twill: a simple scripting language for web browsing
===================================================

twill is a simple scripting language intended for programmatic or automated browsing of websites.

The current version 3.2 supports Python 3.8 to 3.14.

Take a look at the [changelog](https://twill-tools.github.io/twill/changelog.html) to find a list of all changes and improvements made since version 2. For a brief overview of twill's history starting from its early days, see the [acknowledgements and history](https://twill-tools.github.io/twill/overview.html#acknowledgements-and-history) section.

The full [documentation](https://twill-tools.github.io/twill/) is included in the distribution and provided online via [GitHub](https://twill-tools.github.io/twill/) and [ReadTheDocs](https://twill.readthedocs.io/en/latest/).

Copyright (c) 2005-2025 by C. Titus Brown, Ben R. Taylor, Christoph Zwerschke et al.

Newer versions have been created and are maintained by [Christoph Zwerschke](https://github.com/Cito).
 
twill is available for use, modification, and distribution under the MIT license.
